import type { GameData } from "$lib/GameData";
import { idFromString, type Id } from "$lib/Id";
import { isListing } from "$lib/Listing";
import { readListingById } from "$lib/server/mongo";
import {
	badRequestResponse,
	notFoundResponse,
	singleResponse,
} from "$lib/server/responseBodies";
import type { RequestHandler } from "@sveltejs/kit";

export const GET: RequestHandler = async ({ params }): Promise<Response> => {
	const idStr = params["gameid"];

	if (!idStr) {
		return badRequestResponse("missing gameid parameter");
	}

	let id: Id;
	try {
		id = idFromString(idStr);
	} catch (err) {
		return notFoundResponse();
	}

	const game = await readListingById("games", id, isListing<GameData>);

	if (!game) {
		return notFoundResponse();
	}

	return singleResponse(game);
};
