import { isGameData, type GameData } from "$lib/GameData";
import { isListing } from "$lib/Listing";
import { isServerResponse } from "$lib/ServerResponse";
import { error } from "@sveltejs/kit";
import type { PageLoad } from "./$types";

export const load: PageLoad = async ({ fetch, params }) => {
	const url = `/api/games/${params.gameid}`;
	let res: Response;
	let body: unknown;

	try {
		res = await fetch(url);
		body = await res.json();
	} catch (err) {
		error(500, "unable to call API");
	}

	if (res.status === 404) {
		error(404, `Not Found: ${params.gameid}`);
	}

	if (!isServerResponse(body)) {
		error(500, "expected to receive a properly formatted server response body");
	}

	if ("item" in body && isListing<GameData>(body.item, isGameData)) {
		return body.item;
	} else {
		error(500, "expected response body to contain game data");
	}
};
